==> jc-1.4.0.tar.gz: javax/swing/plaf/DimensionUIResource.h <==
// public class javax.swing.plaf.DimensionUIResource

// class file dependencies
// @dep_class 8b86bd0493410b9b java_awt_Dimension
// @dep_class 1db8e8b3f4945eff java_awt_geom_Dimension2D
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4e7cf1bb13d13a7e javax_swing_plaf_DimensionUIResource

// header file dependencies
// @dep_header java_awt_Dimension

#include "java/awt/Dimension.h"

#ifndef _JC_javax_swing_plaf_DimensionUIResource_H_
#define _JC_javax_swing_plaf_DimensionUIResource_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_DimensionUIResource$sub_refs	_jc_javax_swing_plaf_DimensionUIResource$sub_refs;
typedef struct _jc_javax_swing_plaf_DimensionUIResource$sub_nonrefs	_jc_javax_swing_plaf_DimensionUIResource$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_DimensionUIResource$refs	_jc_javax_swing_plaf_DimensionUIResource$refs;
typedef struct _jc_javax_swing_plaf_DimensionUIResource$nonrefs	_jc_javax_swing_plaf_DimensionUIResource$nonrefs;
typedef struct _jc_javax_swing_plaf_DimensionUIResource$object	_jc_javax_swing_plaf_DimensionUIResource$object;

typedef const struct _jc_javax_swing_plaf_DimensionUIResource$vmethods	_jc_javax_swing_plaf_DimensionUIResource$vmethods;
typedef const struct _jc_javax_swing_plaf_DimensionUIResource$vtable	_jc_javax_swing_plaf_DimensionUIResource$vtable;
typedef const struct _jc_javax_swing_plaf_DimensionUIResource$vtype	_jc_javax_swing_plaf_DimensionUIResource$vtype;

// Constructors
extern void _jc_javax_swing_plaf_DimensionUIResource$method$_init$02b806c1c13eed5e(_jc_env *, struct _jc_javax_swing_plaf_DimensionUIResource$object *, jint, jint);

// Virtual methods structure
struct _jc_javax_swing_plaf_DimensionUIResource$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_DimensionUIResource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_geom_Dimension2D$vmethods	java_awt_geom_Dimension2D;
	_jc_java_awt_Dimension$vmethods	java_awt_Dimension;
	_jc_javax_swing_plaf_DimensionUIResource$vmethods	javax_swing_plaf_DimensionUIResource;
};

// Vtype
struct _jc_javax_swing_plaf_DimensionUIResource$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_DimensionUIResource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_DimensionUIResource$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_DimensionUIResource$refs {
    _jc_javax_swing_plaf_DimensionUIResource$sub_refs	javax_swing_plaf_DimensionUIResource;
    _jc_java_awt_Dimension$sub_refs	java_awt_Dimension;
    _jc_java_awt_geom_Dimension2D$sub_refs	java_awt_geom_Dimension2D;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_DimensionUIResource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_DimensionUIResource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_geom_Dimension2D$sub_nonrefs	java_awt_geom_Dimension2D;
    _jc_java_awt_Dimension$sub_nonrefs	java_awt_Dimension;
    _jc_javax_swing_plaf_DimensionUIResource$sub_nonrefs	javax_swing_plaf_DimensionUIResource;
};

// Object instance structure
struct _jc_javax_swing_plaf_DimensionUIResource$object {
	_jc_javax_swing_plaf_DimensionUIResource$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_DimensionUIResource$vtype	*vtype;
	_jc_javax_swing_plaf_DimensionUIResource$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_DimensionUIResource$vtype _jc_javax_swing_plaf_DimensionUIResource$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_DimensionUIResource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_DimensionUIResource$class_object;

#endif	/* _JC_javax_swing_plaf_DimensionUIResource_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/DimensionUIResource.h <==
// public class javax.swing.plaf.DimensionUIResource

// class file dependencies
// @dep_class 8b86bd0493410b9b java_awt_Dimension
// @dep_class 1db8e8b3f4945eff java_awt_geom_Dimension2D
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4e7cf1bb13d13a7e javax_swing_plaf_DimensionUIResource

// header file dependencies
// @dep_header java_awt_Dimension

#include "java/awt/Dimension.h"

#ifndef _JC_javax_swing_plaf_DimensionUIResource_H_
#define _JC_javax_swing_plaf_DimensionUIResource_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_DimensionUIResource$sub_refs	_jc_javax_swing_plaf_DimensionUIResource$sub_refs;
typedef struct _jc_javax_swing_plaf_DimensionUIResource$sub_nonrefs	_jc_javax_swing_plaf_DimensionUIResource$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_DimensionUIResource$refs	_jc_javax_swing_plaf_DimensionUIResource$refs;
typedef struct _jc_javax_swing_plaf_DimensionUIResource$nonrefs	_jc_javax_swing_plaf_DimensionUIResource$nonrefs;
typedef struct _jc_javax_swing_plaf_DimensionUIResource$object	_jc_javax_swing_plaf_DimensionUIResource$object;

typedef const struct _jc_javax_swing_plaf_DimensionUIResource$vmethods	_jc_javax_swing_plaf_DimensionUIResource$vmethods;
typedef const struct _jc_javax_swing_plaf_DimensionUIResource$vtable	_jc_javax_swing_plaf_DimensionUIResource$vtable;
typedef const struct _jc_javax_swing_plaf_DimensionUIResource$vtype	_jc_javax_swing_plaf_DimensionUIResource$vtype;

// Constructors
extern void _jc_javax_swing_plaf_DimensionUIResource$method$_init$02b806c1c13eed5e(_jc_env *, struct _jc_javax_swing_plaf_DimensionUIResource$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_plaf_DimensionUIResource$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_DimensionUIResource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_geom_Dimension2D$vmethods	java_awt_geom_Dimension2D;
	_jc_java_awt_Dimension$vmethods	java_awt_Dimension;
	_jc_javax_swing_plaf_DimensionUIResource$vmethods	javax_swing_plaf_DimensionUIResource;
};

// Vtype
struct _jc_javax_swing_plaf_DimensionUIResource$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_DimensionUIResource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_DimensionUIResource$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_DimensionUIResource$refs {
    _jc_javax_swing_plaf_DimensionUIResource$sub_refs	javax_swing_plaf_DimensionUIResource;
    _jc_java_awt_Dimension$sub_refs	java_awt_Dimension;
    _jc_java_awt_geom_Dimension2D$sub_refs	java_awt_geom_Dimension2D;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_DimensionUIResource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_DimensionUIResource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_geom_Dimension2D$sub_nonrefs	java_awt_geom_Dimension2D;
    _jc_java_awt_Dimension$sub_nonrefs	java_awt_Dimension;
    _jc_javax_swing_plaf_DimensionUIResource$sub_nonrefs	javax_swing_plaf_DimensionUIResource;
};

// Object instance structure
struct _jc_javax_swing_plaf_DimensionUIResource$object {
	_jc_javax_swing_plaf_DimensionUIResource$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_DimensionUIResource$vtype	*vtype;
	_jc_javax_swing_plaf_DimensionUIResource$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_DimensionUIResource$vtype _jc_javax_swing_plaf_DimensionUIResource$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_DimensionUIResource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_DimensionUIResource$class_object;

#endif	/* _JC_javax_swing_plaf_DimensionUIResource_H_ */
